# PYAGATA

<img src="https://i.postimg.cc/G3YXvWWh/agata-logo.png" width="250" height="250">

[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://github.com/gcappon/py_agata/COPYING)
[![GitHub commit](https://img.shields.io/github/last-commit/gcappon/py_agata)](https://github.com/gcappon/py_agata/commits/master)
[![CircleCI](https://circleci.com/gh/gcappon/py_agata.svg?style=shield)](https://circleci.com/gh/gcappon/py_agata)
[![codecov](https://codecov.io/gh/gcappon/py_agata/graph/badge.svg?token=RR39WKLDIK)](https://codecov.io/gh/gcappon/py_agata)

Official Python porting of AGATA (Automated Glucose dATa Analysis): a toolbox to analyse glucose data. 

## Installation

To install it, just run `pip` in your terminal:  
```
pip install py_agata
```

## Citing

If you are using AGATA in your research, please cite it:  
```
Cappon G, Sparacino G, Facchinetti A. AGATA: A toolbox for automated glucose data analysis.  
J Diabetes Sci Technol. 2023. DOI: 10.1177/19322968221147570
```

Link to the paper --> [here](https://doi.org/10.1177/19322968221147570)
